@@ -20,20 +20,21 @@ from __future__ import absolute_import, division, print_function, with_statement
 from supercell.api.metatypes import (ContentType, MediaType, Return, Ok,
                                      Error, OkCreated)
 from supercell.api.requesthandler import RequestHandler
-from supercell.api.decorators import provides, consumes, async
+from supercell.api.decorators import provides, consumes, async, cache
 from supercell.api.service import Service
 
 
 __all__ = [
-        'async',
-        'ContentType',
-        'MediaType',
-        'RequestHandler',
-        'provides',
-        'consumes',
-        'Return',
-        'Ok',
-        'OkCreated',
-        'Error',
-        'Service',
-    ]
+    'async',
+    'cache',
+    'ContentType',
+    'MediaType',
+    'RequestHandler',
+    'provides',
+    'consumes',
+    'Return',
+    'Ok',
+    'OkCreated',
+    'Error',
+    'Service',
+]
